@@ -3,13 +3,13 @@ import os
 import skia
 from .errors import DrawbotError
 from .font import makeTTFontFromSkiaTypeface, tagToInt
-from .text import getShapeFuncForSkiaTypeface
 from .segmenting import textSegments, reorderedSegments
+from .shaping import getShapeFuncForSkiaTypeface
 
 
 class cached_property(object):
 
-    # This exitsts in the stdlib in Python 3.8, but not earlier
+    # This exists in the stdlib in Python 3.8, but not earlier
 
     """A property that is only computed once per instance and then replaces itself
     with an ordinary attribute. Deleting the attribute resets the property."""
@@ -153,6 +153,50 @@ class GraphicsStateMixin:
     def language(self, language):
         self.textStyle = self.textStyle.copy(language=language)
 
+    def listFontVariations(self):
+        ttFont = self.textStyle.ttFont
+        variations = {}
+        if "fvar" in ttFont:
+            nameTable = ttFont["name"]
+            for axis in ttFont["fvar"].axes:
+                axisName = _getName(nameTable, axis.axisNameID)
+                variations[axis.axisTag] = dict(
+                    name=axisName,
+                    minValue=axis.minValue,
+                    defaultValue=axis.defaultValue,
+                    maxValue=axis.maxValue,
+                )
+        return variations
+
+    def listNamedInstances(self):
+        ttFont = self.textStyle.ttFont
+        instances = {}
+        if "fvar" in ttFont:
+            nameTable = ttFont["name"]
+            psName = _getName(nameTable, 6)
+            for instance in ttFont["fvar"].instances:
+                if instance.postscriptNameID != 0xFFFF:
+                    name = _getName(nameTable, instance.postscriptNameID)
+                else:
+                    instanceStyleName = _getName(nameTable, instance.subfamilyNameID)
+                    styleName = _getName(nameTable, 2)
+                    # A dodgy heuristic here:
+                    if instanceStyleName == styleName:
+                        name = psName
+                    else:
+                        name = psName + "_" + instanceStyleName
+                instances[name] = instance.coordinates
+        return instances
+
+
+def _getName(nameTable, nameID):
+    nameRecord = nameTable.getName(nameID, 3, 1, 0x0409)
+    if nameRecord is None:
+        nameRecord = nameTable.getName(nameID, 1, 0, 0)
+    if nameRecord is not None:
+        return nameRecord.toUnicode()
+    return None
+
 
 class GraphicsState(GraphicsStateMixin):
 
@@ -394,7 +438,7 @@ class TextStyle(_ImmutableContainer):
 
     def shape(self, txt):
         segments, baseLevel = textSegments(txt)
-        segments = reorderedSegments(segments, baseLevel)
+        segments = reorderedSegments(segments, baseLevel % 2, lambda item: item[2] % 2)
         startPos = (0, 0)
         glyphsInfo = None
         for runChars, script, bidiLevel, index in segments:
